@@ -6,7 +6,10 @@ import argparse
 import subprocess
 import sys
 
+import requests
+
 from . import api, session
+from .session import open_url
 from .util import get_from_config, QuiltException
 from .registry import app
 
@@ -23,14 +26,24 @@ def cmd_config(catalog_url):
     else:
         api.config(catalog_url)
 
-def cmd_catalog():
+def _test_url(url):
+    try:
+        response = requests.get(url)
+        if response.ok:
+            return True
+        return False
+    except requests.exceptions.ConnectionError:
+        return False
+
+def _launch_local_catalog():
+    """"
+    Launches a docker container to run nginx hosting
+    the Quilt catalog on localhost:3000
     """
-    Run the Quilt catalog locally
-    """
-    open_config = api.config()
+    open_config = api._config()
     command = ["docker", "run", "--rm"]
     env = dict(REGISTRY_URL="http://localhost:5000",
-               S3_PROXY_URL=open_config["s3Proxy"],
+               S3_PROXY_URL="http://localhost:5002",
                ALWAYS_REQUIRE_AUTH="false",
                CATALOG_MODE="LOCAL",
                SSO_AUTH="DISABLED",
@@ -41,6 +54,31 @@ def cmd_catalog():
         command += ["-e", var]
     command += ["-p", "3000:80", "quiltdata/catalog"]
     subprocess.Popen(command)
+
+def _launch_local_s3proxy():
+    """"
+    Launches an s3 proxy (via docker)
+    on localhost:5002
+    """
+    command = ["docker", "run", "--rm"]
+    command += ["-p", "5002:80", "quiltdata/s3proxy"]
+    subprocess.Popen(command)
+
+def cmd_catalog():
+    """
+    Run the Quilt catalog locally
+    """
+
+    local_catalog_url = "http://localhost:3000"
+    local_s3proxy_url = "http://localhost:5002"
+
+    if not _test_url(local_catalog_url):
+        _launch_local_catalog()
+
+    if not _test_url(local_s3proxy_url):
+        _launch_local_s3proxy()
+
+    open_url(local_catalog_url)
     app.run()
 
 def cmd_verify(name, registry, top_hash, dir, extra_files_ok):
